@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
-
 from ucloud.core import client
 
 
 class CompactClient(client.Client):
-    def __init__(self, config, transport=None, middleware=None):
+    def __init__(self, config: dict, transport=None, middleware=None):
         self._config = config
         super(CompactClient, self).__init__(config, transport, middleware)
 
